import { ExtraOptions, RouterModule, Routes } from '@angular/router';
import { NgModule } from '@angular/core';
import {
  NbAuthComponent,
  NbLoginComponent,
  NbLogoutComponent,
  NbRegisterComponent,
  NbRequestPasswordComponent,
  NbResetPasswordComponent,
} from '@nebular/auth';
import { KeycloakAuthGuard } from 'keycloak-angular';
import { AuthGuard } from './core/guards/auth.guard';
import { ExercisesModule } from './features/exercises/exercises.module';
import { routes as DashboardRoutes } from './features/dashboard/dashboard-routing.module';
import { routes as TasksRoutes } from './features/tasks/tasks-routing.module';
import { routes as ExercisesRoutes } from './features/exercises/exercises-routing.module';
import { routes as CoursesRoutes } from './features/courses/courses-routing.module';
import { routes as SolutionsRoutes } from './features/solutions/solutions-routing.module';
import { routes as ModulesRoutes } from './features/modules/modules-routing.module';
import { routes as AttendancesRoutes } from './features/attendances/attendances-routing.module';
import { routes as ProgressRoutes } from './features/progress/progress-routing.module';
import { routes as SearchRoutes } from './features/search/search-routing.module';


export const routes: Routes = [
  {
    path: '',
    children: [
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: DashboardRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: TasksRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: CoursesRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: SolutionsRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: ModulesRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: ExercisesRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: AttendancesRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: ProgressRoutes
      },
      {
        path: '',
        canActivateChild: [AuthGuard],
        children: SearchRoutes
      },
      { path: '**', redirectTo: ''},
    ]
  },
];

const config: ExtraOptions = {
  useHash: false,
  scrollPositionRestoration: 'enabled'
};

@NgModule({
  imports: [RouterModule.forRoot(routes, config)],
  exports: [RouterModule],
})
export class AppRoutingModule {
}
