import { Component, HostBinding, Input, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { AppStateService } from 'app/core/services/app.state.service';
import { Term } from 'app/features/modules/models/term';
import { TermService } from 'app/features/modules/services/term.service';
import { BaseComponent } from 'app/shared/components/base/base.component';
import { takeUntil } from 'rxjs/operators';

@Component({
  selector: 'ngx-term-selection',
  templateUrl: './term-selection.component.html',
  styleUrls: ['./term-selection.component.scss']
})
export class TermSelectionComponent extends BaseComponent implements OnInit {
  _selectedTerm: number;
  termsList: Term[] = [];

  @Input()
  style: string | null;

  @Input()
  class: string | null;

  constructor(
    public appStateService: AppStateService,
    private router: Router
  ) { 
    super();
  }

  ngOnInit(): void {
    this.appStateService.term$
      .pipe(takeUntil(this.unsubscribe))
      .subscribe(term => {
        if (term == null) return;
        this._selectedTerm = term.id;
      });

    this.termsList = this.appStateService.terms;
  }

  get selectedTerm(): number {
    return this._selectedTerm;
  }

  set selectedTerm(value: number) {
    this._selectedTerm = value;
    this.appStateService.setTerm(this.termsList.find(t => t.id === value), true);
  }
}
