import { CourseUnitType } from "./course-unit-type";

import * as moment from 'moment';
import { User } from "app/core/models/user";
import { CourseUnitEventDefinition } from "./course-unit-event-definition";
import { Course } from "./course";

export class CourseUnit {
    id: number;
    name: string;
    type: CourseUnitType;
    lecturers: User[];
    course: Course;
    eventDefinitions: CourseUnitEventDefinition[];

    constructor(unit: any) {
        this.id = unit.id;
        this.name = unit.name;
        this.type = unit.type;
        this.course = unit.course ? new Course(unit.course) : null;
        this.eventDefinitions = unit.eventDefinitions ? unit.eventDefinitions.map(d => new CourseUnitEventDefinition(d)) : [];
        this.lecturers = unit.lecturers ? unit.lecturers.map(l => new User(l)) : [];
    }

    get isLab() {
        return this.type == CourseUnitType.Lab;
    }

    get isLecture() {
        return this.type == CourseUnitType.Lecture;
    }

    get isTut() {
        return this.type == CourseUnitType.Tut;
    }

    get isMisc() {
        return this.type == CourseUnitType.Misc;
    }

    get isSandbox() {
        return this.isMisc && this.name == 'Sandkasten';
    }

    get isDefault() {
        return this.isMisc && this.name == 'Standard';
    }

    get fullName() {
        return this.type == CourseUnitType.Misc 
            ? this.name     
            : `${CourseUnitType.toString(this.type)} ${this.name}`; 
    }

    get shortName() {
        return this.type == CourseUnitType.Misc 
            ? this.name 
            : `${CourseUnitType.toShortString(this.type)}-${this.name}`; 
    }

    lecturedBy(user: User): boolean {
        return this.lecturers.some(l => l.id == user.id);
    }
}