import { Component, Input, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { SubatoPrincipal } from 'app/core/models/principal/subato-principal';
import { User } from 'app/core/models/user';
import { AuthService } from 'app/core/services/auth.service';
import { CourseUnitType } from 'app/features/courses/models/course-unit-type';
import { BaseComponent } from 'app/shared/components/base/base.component';
import { BackendError } from 'app/shared/models/backend-error';
import { takeUntil, flatMap } from 'rxjs/operators';
import { Exercise } from '../../models/exercise';
import { UnitAssessmentProgress } from '../../models/unit-assessment-progress';
import { Origin } from '../../pages/submission/origin';
import { ExerciseService } from '../../services/exercise.service';
import { SubmissionService } from '../../services/submission.service';

@Component({
  selector: 'ngx-submission-list',
  templateUrl: './submission-list.component.html',
  styleUrls: ['./submission-list.component.scss']
})
export class SubmissionListComponent extends BaseComponent implements OnInit {
  @Input() exercise: Exercise;
  @Input() taskId: number;
  @Input() origin: Origin;

  loading: boolean = true;
  error: BackendError;

  principal: SubatoPrincipal;
  onlyOwnUnits: boolean = true;
  assessmentProgresses: UnitAssessmentProgress[] = [];
  CourseUnitType = CourseUnitType;

  constructor(
    private exerciseService: ExerciseService,
    private authService: AuthService,
    private router: Router
  ) {
    super();
  }

  ngOnInit(): void {
    this.loading = true;
    this.authService.principal$
      .pipe(
        takeUntil(this.unsubscribe),
        flatMap(principal => {
          this.principal = principal;
          return this.exerciseService.getAssessmentProgress(this.exercise.id)
        })
      ).subscribe(unitProgresses => {
        this.assessmentProgresses = unitProgresses;
        this.loading = false;
      }, (error: any) => {
        if (BackendError.isBackendError(error)) {
          this.error = error;
          this.loading = false;
        } else {
          throw error;
        }
      });
  }

  get filteredAssessmentProgresses(): UnitAssessmentProgress[] {
    return this.assessmentProgresses.filter(
      s => !this.onlyOwnUnits || s.unit.lecturers.some(l => l.loginName == this.principal.loginName)
    );
  }
}
