import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { AuthService } from 'app/core/services/auth.service';
import { BaseComponent } from 'app/shared/components/base/base.component';
import { combineLatest, forkJoin } from 'rxjs';
import { takeUntil, flatMap } from 'rxjs/operators';
import { BackendError } from 'app/shared/models/backend-error';
import { ExerciseService } from '../../services/exercise.service';
import { Exercise } from '../../models/exercise';
import { ErrorContainerConfig } from 'app/shared/components/error-container/error-container.component';
import { Breadcrumb } from 'app/shared/components/breadcrumbs/breadcrumbs.component';
import { AppStateService } from 'app/core/services/app.state.service';
import { ParamHelper } from 'app/shared/helper/param.helper';

@Component({
  selector: 'ngx-exercise-assessment',
  templateUrl: './exercise-assessment.component.html',
  styleUrls: ['./exercise-assessment.component.scss']
})
export class ExerciseAssessmentComponent extends BaseComponent implements OnInit {
  loading: boolean;
  exercise: Exercise;
  
  error: BackendError;
  errorConfig: ErrorContainerConfig = {
    notFound: {
      message: 'Diese Übung konnten wir leider nicht finden.'
    }
  };

  breadcrumbs: Breadcrumb[] = [];

  constructor(
    private exerciseService: ExerciseService,
    private appStateService: AppStateService,
    private authService: AuthService,
    private route: ActivatedRoute,
    private router: Router) {
    super();
  }

  buildBreadcrumbs(exercise: Exercise) {
    this.breadcrumbs = [
      {
        id: 'exercises',
        params: {
          course_id: exercise.course.id
        },
      },
      {
        id: 'exercise',
        params: {
          exercise_id: exercise.id
        },
        ctx: exercise
      },
      {
        id: 'exerciseAssessment',
        params: {
          exercise_id: exercise.id
        },
      },
    ];
  }
  
  ngOnInit(): void {
    this.loading = true;
    combineLatest(this.route.paramMap, this.authService.principal$)
      .pipe(
        takeUntil(this.unsubscribe),
        flatMap(([params, principal]) => {
          let exerciseId = ParamHelper.parseIdOrThrow(params, "exercise_id");
          return this.exerciseService.getById(exerciseId);
        }))
      .subscribe(exercise => {
        this.exercise = exercise;
        this.appStateService.setCourse(exercise.course);
        this.buildBreadcrumbs(exercise);

        this.loading = false;
      }, (error: any) => {
        if (BackendError.isBackendError(error)) {
          this.error = error;
          this.loading = false;
        } else {
          throw error;
        }
      });
  }
}
