import { HttpClient, HttpParams } from "@angular/common/http";
import { Injectable } from "@angular/core";
import { AppStateService } from "app/core/services/app.state.service";
import { BaseService } from "app/shared/services/base.service";
import { environment } from "environments/environment";
import { Observable } from "rxjs";
import { catchError, map } from "rxjs/operators";
import { SearchResult } from "../models/search-result";
import { BackendError } from "app/shared/models/backend-error";

@Injectable({
    providedIn: 'root'
})
export class SearchService extends BaseService {
    constructor(private http: HttpClient, private appStateService: AppStateService) {
        super();
    }

    search(q: string, courseId: number): Observable<SearchResult> {
        let params = new HttpParams();
        params = params.set("q", q);
        params = params.set("courseId", courseId);

        return this.http.get<SearchResult>(`${environment.backendUrl}/search`, {
            params: params
        }).pipe(
            catchError(e => {
                throw BackendError.parse(e);
            }),
            map(result => new SearchResult(result))
        );
    }
}