import { Component, Input, OnInit } from '@angular/core';
import { BackendError } from 'app/shared/models/backend-error';
import { NotificationService } from 'app/shared/services/notification.service';
import { SolutionService } from '../../services/solution.service';
import { takeUntil, flatMap, map } from 'rxjs/operators';
import { BaseComponent } from 'app/shared/components/base/base.component';
import { EvalResult } from 'app/features/solutions/models/eval-result';
import { Solution } from 'app/features/solutions/models/solution';

@Component({
  selector: 'ngx-acceptance-test',
  templateUrl: './acceptance-test.component.html',
  styleUrls: ['./acceptance-test.component.scss']
})
export class AcceptanceTestComponent extends BaseComponent implements OnInit {
  @Input() solution: Solution;

  isAcceptanceTestRunning: boolean = false;
  acceptanceResult: EvalResult | null = null;

  error: BackendError;

  constructor(
    private solutionService: SolutionService,
    private notificationService: NotificationService
  ) { 
    super();
  }

  ngOnInit(): void {
  }

  runAcceptanceTests() {
    this.isAcceptanceTestRunning = true;
    this.solutionService.runAcceptanceTests(this.solution.id)
    .pipe(takeUntil(this.unsubscribe))
    .subscribe(evalResult => {
      this.acceptanceResult = evalResult;
    }, (error: any) => {
      this.acceptanceResult = null;
      if (BackendError.isBackendError(error)) {
        this.error = error;
        this.notificationService.showError(
          error.format(
            "Fehler bei Ausführung der Abnahmetests" 
          )
        );
      } else {
        throw error;
      }
    }, () => {
      this.isAcceptanceTestRunning = false;
    })
  }
}
