import { Component, OnInit } from '@angular/core';
import { Solution } from 'app/features/solutions/models/solution';
import { SolutionService } from 'app/features/solutions/services/solution.service';
import { BaseComponent } from 'app/shared/components/base/base.component';
import { BackendError } from 'app/shared/models/backend-error';
import { FileTree } from 'app/shared/models/file-tree';
import { NotificationService } from 'app/shared/services/notification.service';
import { takeUntil } from 'rxjs/operators';

@Component({
  selector: 'ngx-default-viewer',
  templateUrl: './default-viewer.component.html',
  styleUrls: ['./default-viewer.component.scss']
})
export class DefaultViewerComponent extends BaseComponent implements OnInit {
  tree: FileTree;
  solution: Solution;

  constructor(
    private solutionService: SolutionService,
    private notificationService: NotificationService
    ) {
    super();
  }

  ngOnInit(): void {
  }

  download() {
    this.solutionService.downloadFile(this.solution.id, this.tree)
    .pipe(takeUntil(this.unsubscribe))
    .subscribe(() => {}, (error: any) => {
      if (BackendError.isBackendError(error)) {
        this.notificationService.showError(
          error.format(
            "Fehler beim Herunterladen der Lösung",
          )
        );
      } else {
        throw error;
      }
    });

  }

}
