import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { BaseComponent } from 'app/shared/components/base/base.component';
import { ErrorContainerConfig } from 'app/shared/components/error-container/error-container.component';
import { BackendError } from 'app/shared/models/backend-error';
import { Observable, of } from 'rxjs';
import { takeUntil, flatMap } from 'rxjs/operators';
import { Language } from '../../models/language';
import { LanguageService } from '../../services/language.service';

@Component({
  selector: 'ngx-edit-language',
  templateUrl: './edit-language.component.html',
  styleUrls: ['./edit-language.component.scss']
})
export class EditLanguageComponent extends BaseComponent implements OnInit {
  loading: boolean = true;
  language: Language;

  error: BackendError;
  errorConfig: ErrorContainerConfig = {
    notFound: {
      message: 'Diese Sprache konnten wir leider nicht finden.'
    }
  };
  
  constructor(
    private languageService: LanguageService,
    private router: Router,
    private route: ActivatedRoute) {
    super();
  }

  ngOnInit(): void {
    this.route.paramMap
      .pipe(
        takeUntil(this.unsubscribe),
        flatMap(params => {
          let langId = params.has("language_id") ? params.get("language_id") : null;

          let loadLanguage: Observable<Language> = of(null);
          if (langId != null) {
            loadLanguage = this.languageService.getById(langId);
          }

          return loadLanguage;
        })
      ).subscribe(language => {
        this.language = language;
        this.loading = false;
      }, error => {
        if (BackendError.isBackendError(error)) {
          this.error = error;
          this.loading = false;
        } else {
          throw error;
        }
      });
  }
}
