package de.hsrm.sls.subato.auth.policy.modules;

import de.hsrm.sls.subato.auth.Role;
import de.hsrm.sls.subato.auth.policy.CheckPolicyRequest;
import de.hsrm.sls.subato.auth.policy.PolicyEvaluator;
import de.hsrm.sls.subato.auth.policy.PolicyRule;
import de.hsrm.sls.subato.auth.policy.courses.CoursesAction;
import de.hsrm.sls.subato.modules.term.Term;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

/**
 * The current user is allowed to view terms
 */
@Component
public class TermViewPolicy implements PolicyRule {
    @Autowired
    @Lazy
    private PolicyEvaluator policy;

    @Override
    public boolean check(CheckPolicyRequest request) {
        if(!request.matches(ModulesAction.TERM_VIEW)) {
            return false;
        }

        var term = (Term) request.getObj();
        return (request.authenticated() && request.getSubject().hasRole(Role.Staff)) || canViewAtLeastOneCourseIn(term);
    }

    private boolean canViewAtLeastOneCourseIn(Term term) {
        return term.getCourses().stream().anyMatch(c -> policy.check(CheckPolicyRequest.fromPrincipal(c, CoursesAction.COURSE_VIEW)));
    }
}