package de.hsrm.sls.subato.auth.principal;

import de.hsrm.sls.subato.auth.Role;
import de.hsrm.sls.subato.courses.course.Course;
import de.hsrm.sls.subato.courses.membership.StaffGroup;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

public class SubatoPrincipal implements UserDetails {
    private long id;
    private String loginName;
    private String firstName;
    private String lastName;
    private String name;
    private String mail;
    private DegreeProgram program;
    private List<CourseStaffMembership> staffMemberships;
    private List<CourseUnit> participatingUnits;
    private List<Role> roles;

    public boolean hasGroup(Course course, StaffGroup group) {
        return hasGroup(course.getId(), group);
    }

    public boolean hasGroup(Long courseId, StaffGroup group) {
        return staffMemberships.stream().anyMatch(
                m -> m.getCourseId() == courseId && m.getGroup().equals(group)
        );
    }

    public boolean hasAnyGroup(Long courseId) {
        return staffMemberships.stream().anyMatch(
                m -> m.getCourseId() == courseId
        );
    }

    public boolean hasAnyGroup() {
        return staffMemberships.size() != 0;
    }

    public boolean isParticipant(long courseId) {
        return participatingUnits.stream().anyMatch(u -> u.getCourseId() == courseId);
    }

    public boolean hasRole(Role role) {
        return roles.stream().anyMatch(r -> r.equals(role));
    }

    public boolean hasAnyRole(Role... roles) {
        return Arrays.stream(roles).anyMatch(r -> hasRole(r));
    }

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getLoginName() {
        return loginName;
    }

    public void setLoginName(String loginName) {
        this.loginName = loginName;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getLastName() {
        return lastName;
    }

    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    public List<CourseStaffMembership> getStaffMemberships() {
        return staffMemberships;
    }

    public void setStaffMemberships(List<CourseStaffMembership> memberships) {
        this.staffMemberships = memberships;
    }

    public List<Role> getRoles() {
        return roles;
    }

    public void setRoles(List<Role> roles) {
        this.roles = roles;
    }

    public List<CourseUnit> getParticipatingUnits() {
        return participatingUnits;
    }

    public void setParticipatingUnits(List<CourseUnit> participatingUnits) {
        this.participatingUnits = participatingUnits;
    }

    public String getMail() {
        return mail;
    }

    public void setMail(String mail) {
        this.mail = mail;
    }

    public DegreeProgram getProgram() {
        return program;
    }

    public void setProgram(DegreeProgram program) {
        this.program = program;
    }

    @Override
    public Collection<? extends GrantedAuthority> getAuthorities() {
        List<GrantedAuthority> grantedAuths = roles.stream().map(r ->
                new SimpleGrantedAuthority(r.toString())).collect(Collectors.toList()
        );

        return grantedAuths;
    }

    @Override
    public String getPassword() {
        return null;
    }

    @Override
    public String getUsername() {
        return loginName;
    }

    @Override
    public boolean isAccountNonExpired() {
        return true;
    }

    @Override
    public boolean isAccountNonLocked() {
        return true;
    }

    @Override
    public boolean isCredentialsNonExpired() {
        return true;
    }

    @Override
    public boolean isEnabled() {
        return true;
    }
}
