package de.hsrm.sls.subato.seed.taskpool;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import de.hsrm.sls.subato.seed.SeedingException;
import de.hsrm.sls.subato.tasks.pool.TaskPool;
import de.hsrm.sls.subato.tasks.pool.TaskPoolRepository;
import de.hsrm.sls.subato.tasks.pool.sync.TaskPoolSyncService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.File;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.util.List;

@Service
@Transactional
public class TaskPoolSeedService {
    private static Logger logger = LoggerFactory.getLogger(TaskPoolSeedService.class);

    @Autowired
    private TaskPoolSyncService taskPoolSyncService;

    @Autowired
    private TaskPoolRepository taskPoolRepository;

    public void seedTaskPools(File seedDir, ObjectMapper objectMapper) {
        try {
            var termsPath = seedDir.toPath().resolve("task_pools.json");
            var json = Files.readString(termsPath, StandardCharsets.UTF_8);
            var poolSeeds = objectMapper.readValue(json,  new TypeReference<List<TaskPoolSeed>>() {});

            logger.debug("Seeding %s task pools...".formatted(poolSeeds.size()));

            for(var poolSeed : poolSeeds) {
                if(poolSeed.getId() != null && taskPoolRepository.existsBySourceId(poolSeed.getId())) {
                    continue;
                }

                var pool = new TaskPool();
                pool.setName(poolSeed.getName());
                pool.setDescription(poolSeed.getDescription());
                pool.setRepositoryUrl(poolSeed.getRepositoryUrl());
                pool.setSourceId(poolSeed.getId());
                pool = taskPoolRepository.save(pool);

                if(pool.isLinkedToRepository()) {
                    taskPoolSyncService.syncPool(pool, false);
                }
            }
        } catch (IOException e) {
            throw new SeedingException(e);
        }
    }
}
