package de.hsrm.sls.subato.solutions.solution;

import org.springframework.data.jpa.domain.Specification;

import static de.hsrm.sls.subato.solutions.solution.SolutionSpecifications.*;

/**
 * Filter request for wrapping available filter options in {@link SolutionService#findAll(SolutionFilter)}
 */
public class SolutionFilter {
    Long submittedById;
    Long exerciseId;
    Long taskId;
    Long submissionId;
    Boolean valid;

    public SolutionFilter submittedById(Long submittedById) {
        this.submittedById = submittedById;
        return this;
    }

    public SolutionFilter exerciseId(Long exerciseId) {
        this.exerciseId = exerciseId;
        return this;
    }

    public SolutionFilter taskId(Long taskId) {
        this.taskId = taskId;
        return this;
    }

    public SolutionFilter submissionId(Long submissionId) {
        this.submissionId = submissionId;
        return this;
    }

    public SolutionFilter valid(Boolean valid) {
        this.valid = valid;
        return this;
    }

    public Specification<Solution> toSpecification() {
        Specification<Solution> spec = Specification.where(null);
        if(submittedById != null) {
            spec = spec.and(submittedByEquals(submittedById));
        }

        if(exerciseId != null) {
            spec = spec.and(exerciseEquals(exerciseId));
        }

        if(taskId != null) {
            spec = spec.and(taskEquals(taskId));
        }

        if(submissionId != null) {
            spec = spec.and(submissionEquals(submissionId));
        }

        if(valid != null) {
            spec = spec.and(isValid(valid));
        }

        return spec;
    }
}
