package de.hsrm.sls.subato.solutions.submit;

import java.util.List;

/**
 * Thrown if a submitted file does not meet the allowed file extensions, configured for the target task.
 *
 * Only applies to top level files!
 * see STEF specification
 */
public class ExtensionNotAllowedException extends RuntimeException {
    private static final String REASON = "Diese Datei (%s) wird von der Aufgabe nicht unterstützt, erlaubte Dateitypen sind: %s";

    private String invalidFileName;
    private List<String> allowedExtensions;

    public ExtensionNotAllowedException(String invalidFileName, List<String> allowedExtensions) {
        this.invalidFileName = invalidFileName;
        this.allowedExtensions = allowedExtensions;
    }

    public String getReason() {
        return REASON.formatted(invalidFileName, String.join(", ", allowedExtensions));
    }
}
