package de.hsrm.sls.subato.user;

import de.hsrm.sls.subato.auth.principal.SubatoPrincipal;
import de.hsrm.sls.subato.auth.policy.CheckPolicyRequest;
import de.hsrm.sls.subato.auth.policy.PolicyEvaluator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class UserService {
    @Autowired
    private UserRepository userRepository;

    @Autowired
    private PolicyEvaluator policy;

    public User findById(long id) {
        return findById(id, true);
    }

    public User findById(long id, boolean raiseException) {
        var user = userRepository.findById(id);

        if(raiseException) {
            return user.orElseThrow(() -> new UserNotFoundException(id));
        } else {
            return user.orElse(null);
        }
    }

    public boolean userExists(long id) {
        return userRepository.existsById(id);
    }

    public User findByLoginName(String loginName) {
        return userRepository.findByLoginNameIgnoreCase(loginName).orElseThrow(() -> new UserNotFoundException("user with login name %s not found".formatted(loginName)));
    }

    public User findByPrincipal(SubatoPrincipal principal) {
        if(principal == null) {
            return null;
        }

        return findById(principal.getId());
    }

    public Page<User> findAll(Pageable page, UserFilter filter) {
        return findAll(page, filter, null);
    }

    public Page<User> findAll(Pageable page, UserFilter filter, String permission) {
        Specification<User> spec = filter.toSpecification();

        if(permission != null) {
            var authSpec = policy.checkAsSpec(CheckPolicyRequest.fromPrincipal(null, permission));
            spec = spec.and(authSpec);
        }

        var users = userRepository.findAll(spec, page);
        return users;
    }

    public List<User> findAll(UserFilter filter, Sort sort) {
        Specification<User> spec = filter.toSpecification();
        return userRepository.findAll(spec, sort);
    }

    public Sort nameSort() {
        return Sort.by(
                Sort.Order.asc(User_.FIRST_NAME),
                Sort.Order.asc(User_.LAST_NAME));
    }
}
